@@ -4,6 +4,8 @@
 #include <errno.h>
 #include <fcntl.h>
 #include <getopt.h>
+#include <grp.h>
+#include <pwd.h>
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
@@ -14,6 +16,9 @@
 #include "log.h"
 #include "logrotate.h"
 
+static char * tabooExts[] = { ".rpmsave", ".rpmorig", "~" };
+static int tabooCount = sizeof(tabooExts) / sizeof(char *);
+
 static int readConfigFile(char * configFile, logInfo * defConfig, 
 			  logInfo ** logsPtr, int * numLogsPtr);
 
@@ -84,6 +89,7 @@ int readConfigPath(char * path, logInfo * defConfig,
     DIR * dir;
     struct dirent * ent;
     int here;
+    int i;
 
     if (stat(path, &sb)) {
 	message(MESS_ERROR, "cannot stat %s: %s\n", path, strerror(errno));
@@ -128,11 +134,18 @@ int readConfigPath(char * path, logInfo * defConfig,
 		(ent->d_name[1] == '.' && !ent->d_name[2]))) {
 		/* noop */
 	    } else if (ent) {
-		if (readConfigFile(ent->d_name, defConfig, logsPtr, 
-				   numLogsPtr)) {
-		    fchdir(here);
-		    close(here);
-		    return 1;
+		for (i = 0; i < tabooCount; i++) {
+		    if (!strcmp(ent->d_name + strlen(ent->d_name) -
+				strlen(tabooExts[i]), tabooExts[i])) break;
+		}
+
+		if (i == tabooCount) {
+		    if (readConfigFile(ent->d_name, defConfig, logsPtr, 
+				       numLogsPtr)) {
+			fchdir(here);
+			close(here);
+			return 1;
+		    }
 		}
 	    }
 	} while (ent);
@@ -152,7 +165,7 @@ static int readConfigFile(char * configFile, logInfo * defConfig,
 			  logInfo ** logsPtr, int * numLogsPtr) {
     int fd;
     char * buf, * endtag;
-    char oldchar;
+    char oldchar, foo;
     int length;
     int lineNum = 1;
     int multiplier;
@@ -161,6 +174,15 @@ static int readConfigFile(char * configFile, logInfo * defConfig,
     char ** scriptDest = NULL;
     logInfo * newlog = defConfig;
     char * start, * chptr;
+    struct group * group;
+    struct passwd * pw;
+    int rc;
+    char createOwner[200], createGroup[200];
+    mode_t createMode;
+
+    /* FIXME: createOWnder and createGroup probably shouldn't be fixed
+       length arrays -- of course, if we aren't run setuid in doesn't
+       matter much */
 
     fd = open(configFile, O_RDONLY);
     if (fd < 0) {
@@ -244,6 +266,55 @@ static int readConfigFile(char * configFile, logInfo * defConfig,
 	    } else if (!strcmp(start, "nocompress")) {
 		newlog->flags &= ~LOG_FLAG_COMPRESS;
 
+		*endtag = oldchar, start = endtag;
+	    } else if (!strcmp(start, "create")) {
+		*endtag = oldchar, start = endtag;
+
+		endtag = start;
+		while (*endtag != '\n') endtag++;
+		while (isspace(*endtag)) endtag--;
+		endtag++;
+		oldchar = *endtag, *endtag = '\0';
+		
+		rc = sscanf(start, "%o %s %s%c", &createMode, 
+				createOwner, createGroup, &foo);
+		if (rc == 4) {
+		    message(MESS_ERROR, "%s:%d extra arguments for "
+			    "create\n", configFile, lineNum, start[length]);
+		    return 1;
+		}
+
+		if (rc > 0)
+		    newlog->createMode = createMode;
+		
+		if (rc > 1) {
+		    pw = getpwnam(createOwner);
+		    if (!pw) {
+			message(MESS_ERROR, "%s:%d unkown user '%s'\n", 
+				configFile, lineNum, createOwner);
+			return 1;
+		    } 
+		    newlog->createUid = pw->pw_uid;
+		    endpwent();
+		} 
+		if (rc > 2) {
+		    group = getgrnam(createGroup);
+		    if (!group) {
+			message(MESS_ERROR, "%s:%d unkown group '%s'\n", 
+				configFile, lineNum, createGroup);
+			return 1;
+		    } 
+		    newlog->createGid = group->gr_gid;
+		    endgrent();
+		} 
+
+		newlog->flags |= LOG_FLAG_CREATE;
+
+		*endtag = oldchar, start = endtag;
+		while (*start != '\n') start++;
+	    } else if (!strcmp(start, "nocreate")) {
+		newlog->flags &= ~LOG_FLAG_CREATE;
+
 		*endtag = oldchar, start = endtag;
 	    } else if (!strcmp(start, "size")) {
 		*endtag = oldchar, start = endtag;
